@@ -1,4 +1,3 @@
-from .gen_docs_common import get_docs_gen_internal_config
 from .main import generate
 from .post_main import CheckWebServerError
 from .sanitization import sanitize
@@ -8,5 +7,4 @@ __all__ = [
     'generate',
     'CheckWebServerError',
     'sanitize',
-    'get_docs_gen_internal_config',
 ]
