@@ -1,5 +1,45 @@
+from pathlib import Path
+
+import pytest
+
+
+@pytest.fixture
+def biskotaki_ci_like_gen_proj(tmp_path):
+    from cookiecutter_python.backend.main import generate
+
+    # GIVEN any existing valid config file to use in generation
+    config_file: Path = tmp_path / 'any_valid_config_file.yml'
+
+    config_file.write_text(
+        """
+default_context:
+    project_name: Anything Project
+    full_name: GG ELA
+    author: GG ELA
+    email: GG.ELA@email.com
+    github_username: ggela1234567
+    project_short_description: Project generated using https://github.com/boromir674/cookiecutter-python-package
+    initialize_git_repo: 'no'
+    interpreters: {"supported-interpreters": ["3.8", "3.9", "3.10", "3.11", "3.12"]}
+    docs_builder: "mkdocs"
+    rtd_python_version: "3.11"
+    cicd: 'stable'
+"""
+    )
+
+    ######## GENERATE Biskotaki from CI Config Yaml ########
+    project_dir: str = generate(
+        no_input=True,
+        offline=True,
+        output_dir=tmp_path / 'gen',  # Path or string to a folder path
+        config_file=str(config_file),  # better be a string
+        default_config=False,
+    )
+    return Path(project_dir)
+
+
 def test_log_file_not_present_in_newly_generated_project(
-    biskotaki_ci_project,
+    biskotaki_ci_like_gen_proj,
 ):
     """Test that the log file is not present inside the `cookiecutter.project_slug` folder"""
     import sys
@@ -9,7 +49,7 @@ def test_log_file_not_present_in_newly_generated_project(
     # exception misbehaviour fixed on Windows?
     import os
 
-    has_developer_fixed_windows_mishap: bool = (
+    has_developer_mitigated_windows_glitch: bool = (
         os.environ.get("BUG_LOG_DEL_WIN") != "permission_error"
     )
 
@@ -26,7 +66,7 @@ def test_log_file_not_present_in_newly_generated_project(
     # logs_folder: Path = LOG_FILE.parent
 
     # WHEN we Generate a new Project, and get the Root Folder (ie repo root dir)
-    runtime_generated_project: Path = biskotaki_ci_project
+    runtime_generated_project: Path = biskotaki_ci_like_gen_proj
 
     # THEN we expect Logs Captured from Runtime Code execution to be written in
     # a file present inside the shell's PWD
@@ -60,7 +100,7 @@ def test_log_file_not_present_in_newly_generated_project(
     # exception misbehaviour fixed on Windows?
     import os
 
-    has_developer_fixed_windows_mishap: bool = (
+    has_developer_mitigated_windows_glitch = (
         os.environ.get("BUG_LOG_DEL_WIN") != "permission_error"
     )
 
@@ -70,11 +110,11 @@ def test_log_file_not_present_in_newly_generated_project(
             running_on_windows
             and (
                 (
-                    has_developer_fixed_windows_mishap
+                    has_developer_mitigated_windows_glitch
                     and not UNINTENTIONALLY_PLACED_LOG_FILE.exists()
                 )
                 or (
-                    not has_developer_fixed_windows_mishap
+                    not has_developer_mitigated_windows_glitch
                     and UNINTENTIONALLY_PLACED_LOG_FILE.exists()
                 )
             )
